@@ -3,8 +3,6 @@ import re
 import unittest
 import unittest.mock
 
-import pytest
-
 import iker.setup
 from iker_tests import resources_directory
 
@@ -131,11 +129,13 @@ class Test(unittest.TestCase):
         self.assertEqual(version_string, "1.2.3")
 
     def test_version_string__with_exception_raised(self):
-        with unittest.mock.patch("iker.setup.version_string_scm", side_effect=Exception()):
-            with pytest.raises(Exception):
-                version_string = iker.setup.version_string(os.path.join(resources_directory, "unittest/setup"),
-                                                           version_file="VERSION",
-                                                           patch_env_var="DUMMY_BUILD",
-                                                           scm_branch_name="dummy_branch",
-                                                           scm_branch_env_var="DUMMY_BRANCH",
-                                                           strict=True)
+        with (
+            (unittest.mock.patch("iker.setup.version_string_scm", side_effect=Exception())),
+            self.assertRaises(Exception),
+        ):
+            iker.setup.version_string(os.path.join(resources_directory, "unittest/setup"),
+                                      version_file="VERSION",
+                                      patch_env_var="DUMMY_BUILD",
+                                      scm_branch_name="dummy_branch",
+                                      scm_branch_env_var="DUMMY_BRANCH",
+                                      strict=True)
